@@ -103,7 +103,7 @@
  * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
  * DEALINGS IN THE SOFTWARE.
  *
- * Copyright 2008-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2008-2015 Horde LLC (http://www.horde.org/)
  *
  * @author  Michael Slusarz <slusarz@horde.org>
  * @package Horde
@@ -303,7 +303,7 @@ Drag = Class.create({
 
     _mouseMove: function(e)
     {
-        var go, eo, po, xy, p, delta, int;
+        var go, eo, po, xy, p, delta;
 
         if (++this.move <= this.options.threshold) {
             return;
