@@ -2,7 +2,7 @@
 /**
  * Kronolith wrapper for the base AJAX framework handler.
  *
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -90,7 +90,7 @@ class Kronolith_Ajax
             'name' => $registry->get('name'),
             'has_tasks' => intval($has_tasks),
             'has_resources' => intval(!empty($conf['resource']['driver'])),
-            'login_view' => ($prefs->getValue('defaultview') == 'workweek') ? 'week' : $prefs->getValue('defaultview'),
+            'login_view' => $prefs->getValue('defaultview'),
             'default_calendar' => 'internal|' . Kronolith::getDefaultCalendar(Horde_Perms::EDIT),
             'max_events' => intval($prefs->getValue('max_events')),
             'date_format' => Horde_Core_Script_Package_Datejs::translateFormat(
