@@ -2,7 +2,7 @@
 /**
  * Defines the AJAX actions used in Kronolith.
  *
- * Copyright 2012-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2012-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -275,7 +275,7 @@ class Kronolith_Ajax_Application_Handler extends Horde_Core_Ajax_Application_Han
                 // become corrupt.
                 $newEvent = clone($event);
                 $newEvent->recurrence = new Horde_Date_Recurrence($event->start);
-                $newEvent->readForm();
+                $newEvent->readForm($event);
 
                 // Create an exception event from the new properties.
                 $exception = $this->_copyEvent($event, $newEvent, $attributes);
@@ -1414,7 +1414,7 @@ EOT;
      * before saving an event to give the user feedback.
      *
      * The following arguments are expected:
-     *   - r:  An array of resource identifiers.
+     *   - r:  A comma separated string of resource identifiers.
      *   - s:  The event start time to check.
      *   - e:  The event end time to check.
      *   - u:  The event uid, if not a new event.
@@ -1438,11 +1438,7 @@ EOT;
         $event->start->setTimezone(date_default_timezone_get());
         $event->end->setTimezone(date_default_timezone_get());
         $results = array();
-        $r = $this->vars->r;
-        if (!is_array($r)) {
-            $r = array($r);
-        }
-        foreach ($r as $id) {
+        foreach (explode(',', $this->vars->r) as $id) {
             $resource = Kronolith::getDriver('Resource')->getResource($id);
             $results[$id] = $resource->getResponse($event);
         }
@@ -1642,6 +1638,7 @@ EOT;
         $nevent->url = $copy->url;
         $nevent->status = $copy->status;
         $nevent->attendees = $copy->attendees;
+        $nevent->setResources($copy->getResources());
         $nevent->start = $rstart;
         $nevent->end = $rend;
         $nevent->initialized = true;
