@@ -32,14 +32,15 @@ class Kronolith_Api extends Horde_Registry_Api
      * Returns the last modification timestamp for the given uid.
      *
      * @param string $uid      The uid to look for.
+     * @param string $calendar The calendar to search in.
      *
      * @return integer  The timestamp for the last modification of $uid.
      */
-    public function modified($uid)
+    public function modified($uid, $calendar = null)
     {
-        $modified = $this->getActionTimestamp($uid, 'modify');
+        $modified = $this->getActionTimestamp($uid, 'modify', $calendar);
         if (empty($modified)) {
-            $modified = $this->getActionTimestamp($uid, 'add');
+            $modified = $this->getActionTimestamp($uid, 'add', $calendar);
         }
         return $modified;
     }
@@ -56,6 +57,8 @@ class Kronolith_Api extends Horde_Registry_Api
      */
     public function browse($path = '', $properties = array())
     {
+        global $injector, $registry;
+
         // Default properties.
         if (!$properties) {
             $properties = array('name', 'icon', 'browseable');
@@ -66,6 +69,7 @@ class Kronolith_Api extends Horde_Registry_Api
         }
         $path = trim($path, '/');
         $parts = explode('/', $path);
+        $currentUser = $registry->getAuth();
 
         if (empty($path)) {
             // This request is for a list of all users who have calendars
@@ -78,9 +82,12 @@ class Kronolith_Api extends Horde_Registry_Api
 
             $results = array();
             foreach (array_keys($owners) as $owner) {
-                $path = 'kronolith/' . $owner;
+                $path = 'kronolith/' . $registry->convertUsername($owner, false);
                 if (in_array('name', $properties)) {
-                    $results[$path]['name'] = $owner;
+                    $results[$path]['name'] = $injector
+                        ->getInstance('Horde_Core_Factory_Identity')
+                        ->create($owner)
+                        ->getName();
                 }
                 if (in_array('icon', $properties)) {
                     $results[$path]['icon'] = Horde_Themes::img('user.png');
@@ -88,43 +95,18 @@ class Kronolith_Api extends Horde_Registry_Api
                 if (in_array('browseable', $properties)) {
                     $results[$path]['browseable'] = true;
                 }
-                if (in_array('contenttype', $properties)) {
-                    $results[$path]['contenttype'] =
-                        'httpd/unix-directory';
-                }
-                if (in_array('contentlength', $properties)) {
-                    $results[$path]['contentlength'] = 0;
-                }
-                if (in_array('modified', $properties)) {
-                    $results[$path]['modified'] =
-                        $_SERVER['REQUEST_TIME'];
-                }
-                if (in_array('created', $properties)) {
-                    $results[$path]['created'] = 0;
-                }
-
-                // CalDAV Properties from RFC 4791 and
-                // draft-desruisseaux-caldav-sched-03
-                $caldavns = 'urn:ietf:params:xml:ns:caldav';
-                $kronolith_rpc_base = $GLOBALS['registry']->get('webroot', 'horde') . '/rpc/kronolith/';
-                if (in_array($caldavns . ':calendar-home-set', $properties)) {
-                    $results[$path][$caldavns . ':calendar-home-set'] =  Horde::url($kronolith_rpc_base . urlencode($owner), true);
-                }
-
-                if (in_array($caldavns . ':calendar-user-address-set', $properties)) {
-                    // FIXME: Add the calendar owner's email address from
-                    // their Horde Identity
-                }
             }
             return $results;
 
         } elseif (count($parts) == 1) {
             // This request is for all calendars owned by the requested user
-            $owner = $parts[0] == '-system-' ? '' : $parts[0];
-            $calendars = $GLOBALS['injector']->getInstance('Kronolith_Shares')->listShares(
-                $GLOBALS['registry']->getAuth(),
-                array('perm' => Horde_Perms::SHOW,
-                      'attributes' => $owner));
+            $owner = $parts[0] == '-system-' ? '' : $registry->convertUsername($parts[0], true);
+            $calendars = $injector->getInstance('Kronolith_Shares')
+                ->listShares(
+                    $currentUser,
+                    array('perm' => Horde_Perms::SHOW,
+                          'attributes' => $owner)
+                );
             $results = array();
             foreach ($calendars as $calendarId => $calendar) {
                 if ($parts[0] == '-system-' && $calendar->get('owner')) {
@@ -136,39 +118,28 @@ class Kronolith_Api extends Horde_Registry_Api
                     $results[$retpath . '.ics']['name'] = Kronolith::getLabel($calendar);
                 }
                 if (in_array('displayname', $properties)) {
-                    $results[$retpath]['displayname'] = rawurlencode(Kronolith::getLabel($calendar));
-                    $results[$retpath . '.ics']['displayname'] = rawurlencode(Kronolith::getLabel($calendar)) . '.ics';
+                    $results[$retpath]['displayname'] = Kronolith::getLabel($calendar);
+                    $results[$retpath . '.ics']['displayname'] = Kronolith::getLabel($calendar) . '.ics';
+                }
+                if (in_array('owner', $properties)) {
+                    $results[$retpath]['owner'] = $results[$retpath . '.ics']['owner'] = $calendar->get('owner')
+                        ? $registry->convertUsername($calendar->get('owner'), false)
+                        : '-system-';
                 }
                 if (in_array('icon', $properties)) {
                     $results[$retpath]['icon'] = Horde_Themes::img('kronolith.png');
                     $results[$retpath . '.ics']['icon'] = Horde_Themes::img('mime/icalendar.png');
                 }
                 if (in_array('browseable', $properties)) {
-                    $results[$retpath]['browseable'] = $calendar->hasPermission($GLOBALS['registry']->getAuth(), Horde_Perms::READ);
+                    $results[$retpath]['browseable'] = $calendar->hasPermission($currentUser, Horde_Perms::READ);
                     $results[$retpath . '.ics']['browseable'] = false;
                 }
+                if (in_array('read-only', $properties)) {
+                    $results[$retpath]['read-only'] = $results[$retpath . '.ics']['read-only'] = !$calendar->hasPermission($currentUser, Horde_Perms::EDIT);
+                }
                 if (in_array('contenttype', $properties)) {
-                    $results[$retpath]['contenttype'] = 'httpd/unix-directory';
                     $results[$retpath . '.ics']['contenttype'] = 'text/calendar';
                 }
-                if (in_array('contentlength', $properties)) {
-                    $results[$retpath]['contentlength'] = 0;
-                    // FIXME: This is a hack.  If the content length is longer
-                    // than the actual data then some WebDAV clients will
-                    // report an error when the file EOF is received.  Ideally
-                    // we should determine the actual size of the .ics and
-                    // report it here, but the performance hit may be
-                    // prohibitive.  This requires further investigation.
-                    $results[$retpath . '.ics']['contentlength'] = 1;
-                }
-                if (in_array('modified', $properties)) {
-                    $results[$retpath]['modified'] = $_SERVER['REQUEST_TIME'];
-                    $results[$retpath . '.ics']['modified'] = $_SERVER['REQUEST_TIME'];
-                }
-                if (in_array('created', $properties)) {
-                    $results[$retpath]['created'] = 0;
-                    $results[$retpath . '.ics']['created'] = 0;
-                }
             }
             return $results;
 
@@ -177,9 +148,20 @@ class Kronolith_Api extends Horde_Registry_Api
             // This request is browsing into a specific calendar.  Generate
             // the list of items and represent them as files within the
             // directory.
+            try {
+                $calendar = $injector->getInstance('Kronolith_Shares')
+                    ->getShare($parts[1]);
+            } catch (Horde_Exception_NotFound $e) {
+                throw new Kronolith_Exception(_("Invalid calendar requested."), 404);
+            } catch (Horde_Share_Exception $e) {
+                throw new Kronolith_Exception($e->getMessage, 500);
+            }
             $kronolith_driver = Kronolith::getDriver(null, $parts[1]);
             $events = $kronolith_driver->listEvents();
             $icon = Horde_Themes::img('mime/icalendar.png');
+            $owner = $calendar->get('owner')
+                ? $registry->convertUsername($calendar->get('owner'), false)
+                : '-system-';
             $results = array();
             foreach ($events as $dayevents) {
                 foreach ($dayevents as $event) {
@@ -187,6 +169,9 @@ class Kronolith_Api extends Horde_Registry_Api
                     if (in_array('name', $properties)) {
                         $results[$key]['name'] = $event->getTitle();
                     }
+                    if (in_array('owner', $properties)) {
+                        $results[$key]['owner'] = $owner;
+                    }
                     if (in_array('icon', $properties)) {
                         $results[$key]['icon'] = $icon;
                     }
@@ -196,18 +181,8 @@ class Kronolith_Api extends Horde_Registry_Api
                     if (in_array('contenttype', $properties)) {
                         $results[$key]['contenttype'] = 'text/calendar';
                     }
-                    if (in_array('contentlength', $properties)) {
-                        // FIXME: This is a hack.  If the content length is
-                        // longer than the actual data then some WebDAV
-                        // clients will report an error when the file EOF is
-                        // received.  Ideally we should determine the actual
-                        // size of the data and report it here, but the
-                        // performance hit may be prohibitive.  This requires
-                        // further investigation.
-                        $results[$key]['contentlength'] = 1;
-                    }
                     if (in_array('modified', $properties)) {
-                        $results[$key]['modified'] = $this->modified($event->uid);
+                        $results[$key]['modified'] = $this->modified($event->uid, $parts[1]);
                     }
                     if (in_array('created', $properties)) {
                         $results[$key]['created'] = $this->getActionTimestamp($event->uid, 'add');
@@ -226,7 +201,7 @@ class Kronolith_Api extends Horde_Registry_Api
                 $result = array(
                     'data' => $this->export($event->uid, 'text/calendar'),
                     'mimetype' => 'text/calendar');
-                $modified = $this->modified($event->uid);
+                $modified = $this->modified($event->uid, $parts[1]);
                 if (!empty($modified)) {
                     $result['mtime'] = $modified;
                 }
@@ -236,12 +211,12 @@ class Kronolith_Api extends Horde_Registry_Api
                       array_key_exists(substr($parts[1], 0, -4), Kronolith::listInternalCalendars(false, Horde_Perms::READ))) {
                 // This request is for an entire calendar (calendar.ics).
                 $ical_data = $this->exportCalendar(substr($parts[1], 0, -4), 'text/calendar');
-                $result = array('data'          => $ical_data,
-                                'mimetype'      => 'text/calendar',
-                                'contentlength' => strlen($ical_data),
-                                'mtime'         => $_SERVER['REQUEST_TIME']);
-
-                return $result;
+                return array(
+                    'data'          => $ical_data,
+                    'mimetype'      => 'text/calendar',
+                    'contentlength' => strlen($ical_data),
+                    'mtime'         => $_SERVER['REQUEST_TIME']
+                );
             } else {
                 // All other requests are a 404: Not Found
                 return false;
@@ -295,7 +270,11 @@ class Kronolith_Api extends Horde_Registry_Api
         // Store all currently existings UIDs. Use this info to delete UIDs not
         // present in $content after processing.
         $ids = array();
-        $uids_remove = array_flip($this->listUids($calendar));
+        if (count($parts) == 2) {
+            $uids_remove = array_flip($this->listUids($calendar));
+        } else {
+            $uids_remove = array();
+        }
 
         switch ($content_type) {
         case 'text/calendar':
@@ -310,53 +289,61 @@ class Kronolith_Api extends Horde_Registry_Api
             }
 
             $kronolith_driver = Kronolith::getDriver();
+            $kronolith_driver->open($parts[1]);
+            $history = $GLOBALS['injector']->getInstance('Horde_History');
             foreach ($iCal->getComponents() as $content) {
                 if ($content instanceof Horde_Icalendar_Vevent) {
                     $event = $kronolith_driver->getEvent();
                     $event->fromiCalendar($content);
                     $uid = $event->uid;
-                    // Remove from uids_remove list so we won't delete in the
-                    // end.
-                    if (isset($uids_remove[$uid])) {
+                    if ($uid) {
+                        // Remove from uids_remove list so we won't delete in
+                        // the end.
                         unset($uids_remove[$uid]);
-                    }
-                    try {
-                        $existing_event = $kronolith_driver->getByUID($uid, array($calendar));
-                        // Check if our event is newer then the existing - get
-                        // the event's history.
-                        $created = $modified = null;
                         try {
-                            $history = $GLOBALS['injector']->getInstance('Horde_History');
-                            $created = $history->getActionTimestamp(
-                                'kronolith:' . $calendar . ':' . $uid, 'add');
-                            $modified = $history->getActionTimestamp(
-                                'kronolith:' . $calendar . ':' . $uid, 'modify');
-                            /* The history driver returns 0 for not found. If 0
-                             * or null does not matter, strip this */
-                            if ($created == 0) {
-                                $created = null;
+                            $existing_event = $kronolith_driver->getByUID(
+                                $uid, array($calendar)
+                            );
+                            // Check if our event is newer then the existing -
+                            // get the event's history.
+                            $created = $modified = null;
+                            try {
+                                $created = $history->getActionTimestamp(
+                                    'kronolith:' . $calendar . ':' . $uid,
+                                    'add'
+                                );
+                                $modified = $history->getActionTimestamp(
+                                    'kronolith:' . $calendar . ':' . $uid,
+                                    'modify'
+                                );
+                                /* The history driver returns 0 for not
+                                 * found. If 0 or null does not matter, strip
+                                 * this */
+                                if ($created == 0) {
+                                    $created = null;
+                                }
+                                if ($modified == 0) {
+                                    $modified = null;
+                                }
+                            } catch (Horde_Exception $e) {
                             }
-                            if ($modified == 0) {
-                                $modified = null;
+                            if (empty($modified) && !empty($created)) {
+                                $modified = $created;
                             }
-                        } catch (Horde_Exception $e) {
-                        }
-                        if (empty($modified) && !empty($created)) {
-                            $modified = $created;
-                        }
-                        try {
-                            if (!empty($modified) &&
-                                $modified >= $content->getAttribute('LAST-MODIFIED')) {
-                                // LAST-MODIFIED timestamp of existing entry
-                                // is newer: don't replace it.
-                                continue;
+                            try {
+                                if (!empty($modified) &&
+                                    $modified >= $content->getAttribute('LAST-MODIFIED')) {
+                                    // LAST-MODIFIED timestamp of existing
+                                    // entry is newer: don't replace it.
+                                    continue;
+                                }
+                            } catch (Horde_Icalendar_Exception $e) {
                             }
-                        } catch (Horde_Icalendar_Exception $e) {
-                        }
 
-                        // Don't change creator/owner.
-                        $event->creator = $existing_event->creator;
-                    } catch (Horde_Exception_NotFound $e) {
+                            // Don't change creator/owner.
+                            $event->creator = $existing_event->creator;
+                        } catch (Horde_Exception_NotFound $e) {
+                        }
                     }
 
                     // Save entry.
@@ -756,37 +743,8 @@ class Kronolith_Api extends Horde_Registry_Api
                 $iCal->addComponent($content);
             }
 
-            $components = $iCal->getComponents();
-            if (count($components) == 0) {
-                throw new Kronolith_Exception(_("No iCalendar data was found."));
-            }
-
-            $ids = array();
-            $recurrences = array();
-            foreach ($components as $content) {
-                if ($content instanceof Horde_Icalendar_Vevent) {
-                    // Need to ensure that the original recurring event is
-                    // added before any of the instance exceptions. Easiest way
-                    // to do that is just add all the recurrence-id entries last
-                    try {
-                        $content->getAttribute('RECURRENCE-ID');
-                        $recurrences[] = $content;
-                    } catch (Horde_Icalendar_Exception $e) {
-                        $ids[] = $this->_addiCalEvent($content, $kronolith_driver);
-                    }
-                }
-            }
-
-            if (count($ids) == 0) {
-                throw new Kronolith_Exception(_("No iCalendar data was found."));
-            }
-
-            // Now add all the exception instances
-            foreach ($recurrences as $recurrence) {
-                $ids[] = $this->_addiCalEvent($recurrence, $kronolith_driver, true);
-            }
-
-            return $ids;
+            $ical_importer = new Kronolith_Icalendar_Handler_Base($iCal, $kronolith_driver);
+            return $ical_importer->process();
 
             case 'activesync':
                 $event = $kronolith_driver->getEvent();
@@ -812,19 +770,18 @@ class Kronolith_Api extends Horde_Registry_Api
     {
         $event = $driver->getEvent();
         $event->fromiCalendar($content);
-        // Check if the entry already exists in the data source,
-        // first by UID.
+        // Check if the entry already exists in the data source, first by UID.
         if (!$exception) {
             try {
-                $driver->getByUID($uid, array($driver->calendar));
+                $driver->getByUID($event->uid, array($driver->calendar));
                 throw new Kronolith_Exception(sprintf(_("%s Already Exists"), $event->uid));
             } catch (Horde_Exception $e) {}
         }
 
         $result = $driver->search($event);
         // Check if the match really is an exact match:
-        if (is_array($result) && count($result) > 0) {
-            foreach($result as $match) {
+        foreach ($result as $days) {
+            foreach ($days as $match) {
                 if ($match->start == $event->start &&
                     $match->end == $event->end &&
                     $match->title == $event->title &&
