@@ -5,7 +5,7 @@
  * This file defines Horde's core API interface. Other core Horde libraries
  * can interact with Kronolith through this API.
  *
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -47,7 +47,7 @@ class Kronolith_Application extends Horde_Registry_Application
 
     /**
      */
-    public $version = 'H5 (4.2.2)';
+    public $version = 'H5 (4.2.9)';
 
     /**
      * Global variables defined:
@@ -670,18 +670,18 @@ class Kronolith_Application extends Horde_Registry_Application
      */
     public function davGetCollections($user)
     {
-        $opts = array('perm' => Horde_Perms::SHOW);
-        $shares = $GLOBALS['injector']
-            ->getInstance('Kronolith_Shares')
-            ->listShares($user, $opts);
-        $dav = $GLOBALS['injector']
-            ->getInstance('Horde_Dav_Storage');
+        global $calendar_manager, $injector, $registry;
+
+        $hordeUser = $registry->convertUsername($user, true);
+        $shares = $injector->getInstance('Kronolith_Shares')
+            ->listShares($hordeUser);
+        $dav = $injector->getInstance('Horde_Dav_Storage');
         $calendars = array();
         foreach ($shares as $id => $share) {
             if ($user == '-system-' && $share->get('owner')) {
                 continue;
             }
-            $calendar = $GLOBALS['calendar_manager']
+            $calendar = $calendar_manager
                 ->getEntry(Kronolith::ALL_CALENDARS, $id)
                 ->toHash();
             try {
@@ -695,14 +695,18 @@ class Kronolith_Application extends Horde_Registry_Application
                     $calendar['caldav'],
                 'principaluri' => 'principals/' . $user,
                 '{http://sabredav.org/ns}owner-principal' =>
-                    'principals/' . ($share->get('owner') ?: '-system-'),
+                    'principals/'
+                        . ($share->get('owner')
+                           ? $registry->convertUsername($share->get('owner'), false)
+                           : '-system-'
+                        ),
                 '{DAV:}displayname' => Kronolith::getLabel($share),
                 '{' . CalDAV\Plugin::NS_CALDAV . '}calendar-description' =>
                     $share->get('desc'),
                 '{http://apple.com/ns/ical/}calendar-color' =>
                     $share->get('color') . 'ff',
                 '{' . CalDAV\Plugin::NS_CALDAV . '}supported-calendar-component-set' => new CalDAV\Property\SupportedCalendarComponentSet(array('VEVENT')),
-                '{http://sabredav.org/ns}read-only' => !$share->hasPermission($user, Horde_Perms::EDIT),
+                '{http://sabredav.org/ns}read-only' => !$share->hasPermission($hordeUser, Horde_Perms::EDIT),
             );
         }
         return $calendars;
@@ -811,62 +815,10 @@ class Kronolith_Application extends Horde_Registry_Application
         if (!$ical->parsevCalendar($data)) {
             throw new Kronolith_Exception(_("There was an error importing the iCalendar data."));
         }
-
-        $kronolith_driver = Kronolith::getDriver(null, $internal);
-
-        foreach ($ical->getComponents() as $content) {
-            if (!($content instanceof Horde_Icalendar_Vevent)) {
-                continue;
-            }
-
-            $event = $kronolith_driver->getEvent();
-            $event->fromiCalendar($content, true);
-
-            try {
-                try {
-                    $existing_id = $dav->getInternalObjectId($object, $internal)
-                        ?: preg_replace('/\.ics$/', '', $object);
-                } catch (Horde_Dav_Exception $e) {
-                    $existing_id = $object;
-                }
-                $existing_event = $kronolith_driver->getEvent($existing_id);
-                /* Check if our event is newer then the existing - get the
-                 * event's history. */
-                $existing_event->loadHistory();
-                $modified = $existing_event->modified
-                    ?: $existing_event->created;
-                try {
-                    if (!empty($modified) &&
-                        $content->getAttribute('LAST-MODIFIED') < $modified->timestamp()) {
-                        /* LAST-MODIFIED timestamp of existing entry is newer:
-                         * don't replace it. */
-                        continue;
-                    }
-                } catch (Horde_Icalendar_Exception $e) {
-                }
-
-                // Don't change creator/owner.
-                $event->creator = $existing_event->creator;
-            } catch (Horde_Exception_NotFound $e) {
-                $existing_event = null;
-            }
-
-            // Save entry.
-            $id = $event->save();
-
-            if (!$existing_event) {
-                $dav->addObjectMap($id, $object, $internal);
-            }
-
-            // Send iTip messages.
-            // Notifications will get lost, there is no way to return messages
-            // to clients.
-            Kronolith::sendITipNotifications(
-                $event,
-                new Horde_Notification_Handler(new Horde_Notification_Storage_Object()),
-                Kronolith::ITIP_REQUEST
-            );
-        }
+        $importer = new Kronolith_Icalendar_Handler_Dav(
+            $ical, Kronolith::getDriver(null, $internal), array('object' => $object)
+        );
+        $importer->process();
     }
 
     /**
