@@ -2,7 +2,7 @@
 /**
  * Kronolith_Calendar_External_Tasks defines an API for single task lists.
  *
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -71,7 +71,7 @@ class Kronolith_Calendar_External_Tasks extends Kronolith_Calendar_External
                 true,
                 -1
             )
-                . $registry->getAuth() . '/'
+                . $registry->convertUsername($registry->getAuth(), false) . '/'
                 . $injector->getInstance('Horde_Dav_Storage')
                     ->getExternalCollectionId($this->_share->getName(), 'tasks')
                 . '/';
@@ -86,7 +86,7 @@ class Kronolith_Calendar_External_Tasks extends Kronolith_Calendar_External
             -1
         )
             . ($this->_share->get('owner')
-                ? $this->_share->get('owner')
+                ? $registry->convertUsername($this->_share->get('owner'), false)
                 : '-system-')
             . '/'
             . $this->_share->getName() . '.ics';
