@@ -3,7 +3,7 @@
  * Kronolith_Calendar_Internal defines an API for single internal (share)
  * calendars.
  *
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -143,6 +143,7 @@ class Kronolith_Calendar_Internal extends Kronolith_Calendar
             $calendar_manager->get(Kronolith::DISPLAY_CALENDARS)
         );
         $hash['edit']  = $this->hasPermission(Horde_Perms::EDIT);
+        $hash['delete']  = $this->hasPermission(Horde_Perms::DELETE);
         try {
             $hash['caldav'] = Horde::url(
                 $registry->get('webroot', 'horde')
@@ -152,7 +153,7 @@ class Kronolith_Calendar_Internal extends Kronolith_Calendar
                 true,
                 -1
             )
-                . $registry->getAuth() . '/'
+                . $registry->convertUsername($registry->getAuth(), false) . '/'
                 . $injector->getInstance('Horde_Dav_Storage')
                     ->getExternalCollectionId($id, 'calendar')
                 . '/';
@@ -166,7 +167,7 @@ class Kronolith_Calendar_Internal extends Kronolith_Calendar
             true,
             -1
         )
-            . ($this->owner() ? $this->owner() : '-system-') . '/'
+            . ($this->owner() ? $registry->convertUsername($this->owner(), false) : '-system-') . '/'
             . $id . '.ics';
         $hash['feed']  = (string)Kronolith::feedUrl($id);
         $hash['embed'] = Kronolith::embedCode($id);
