@@ -3,7 +3,7 @@
  * Kronolith_Calendar_Resource defines an API for single internal resource
  * calendars.
  *
- * Copyright 2010-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2010-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -103,7 +103,12 @@ class Kronolith_Calendar_Resource extends Kronolith_Calendar
      */
     public function toHash()
     {
-        $owner = $GLOBALS['registry']->isAdmin();
+        global $registry, $injector;
+
+        $owner = $registry->isAdmin() ||
+                 $injector->getInstance('Horde_Core_Perms')
+                    ->hasAppPermission('resource_management');
+
         $hash = parent::toHash();
 
         $hash['id']    = $this->_resource->getId();
