@@ -1,8 +1,6 @@
 <?php
 /**
- * Kronolith_CalendarsManager::
- *
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2013-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -16,11 +14,6 @@
 /**
  * Handles management of the various global calendar lists.
  *
- * Copyright 2013-2014 Horde LLC (http://www.horde.org/)
- *
- * See the enclosed file COPYING for license information (GPL). If you
- * did not receive this file, see http://www.horde.org/licenses/gpl.
- *
  * @author   Michael J Rubinsky <mrubinsk@horde.org>
  * @license  http://www.horde.org/licenses/gpl GPL
  * @package  Kronolith
@@ -124,21 +117,32 @@ class Kronolith_CalendarsManager
      *  - displayRemote
      *  - displayExternal
      *  - displayHolidays
+     *
+     * @param string $user  The user to initialize for, if not the current.
+     *                      @since 4.2.4
      */
-    public function __construct()
+    public function __construct($user = null)
     {
+        $emptyUser = false;
+        if (empty($user)) {
+            $user = $GLOBALS['registry']->getAuth();
+            $emptyUser = true;
+        }
         // Always perform the display related checks.
         $this->_checkDisplayCals();
         $this->_checkToggleCalendars();
 
         // Check that all selected shares still exist.
-        foreach (Kronolith::listInternalCalendars() as $id => $calendar) {
+        foreach (Kronolith::listInternalCalendars(false, Horde_Perms::SHOW, $user) as $id => $calendar) {
             $this->_allCalendars[$id] = new Kronolith_Calendar_Internal(array('share' => $calendar));
         }
         $this->_displayCalendars = array_intersect($this->_displayCalendars, array_keys($this->_allCalendars));
 
-        // Check that the user owns a calendar.
-        $this->_checkForOwnedCalendar();
+        // Check that the user owns a calendar if we aren't loading a different
+        // user.
+        if ($emptyUser) {
+            $this->_checkForOwnedCalendar();
+        }
     }
 
     /**
@@ -163,6 +167,7 @@ class Kronolith_CalendarsManager
                 return $this->_allResource;
             }
             return $this->_getAllResource();
+
         case Kronolith::ALL_REMOTE_CALENDARS:
             if ($this->_allRemote !== false) {
                 return $this->_allRemote;
@@ -188,11 +193,13 @@ class Kronolith_CalendarsManager
                 return $this->_displayExternal;
             }
             return $this->_getDisplayExternal();
+
         case Kronolith::ALL_HOLIDAYS:
             if ($this->_allHolidays !== false) {
                 return $this->_allHolidays;
             }
             return $this->_getAllHolidays();
+
         case Kronolith::DISPLAY_HOLIDAYS:
             if ($this->_displayHolidays !== false) {
                 return $this->_displayHolidays;
@@ -288,6 +295,10 @@ class Kronolith_CalendarsManager
                     ? $pref_val
                     : array();
             }
+
+            // Run through getDisplayExternal to trim any that no longer exist.
+            $this->_getDisplayExternal();
+
             if (empty($conf['holidays']['enable'])) {
                 $this->_displayHolidays = array();
                 $this->_displayHolidaysInternal = array();
@@ -468,13 +479,21 @@ class Kronolith_CalendarsManager
                 }
 
                 foreach ($categories as $name => $description) {
-                    $this->_allExternal[$api . '/' . $name] = new Kronolith_Calendar_External(array('api' => $api, 'name' => $description['title'], 'id' => $name, 'type' => $description['type']));
+                    if (empty($description['background'])) {
+                        $description['background'] = '#dddddd';
+                    }
+                    $this->_allExternal[$api . '/' . $name] = new Kronolith_Calendar_External(array(
+                        'api' => $api,
+                        'name' => $description['title'],
+                        'id' => $name,
+                        'type' => $description['type'],
+                        'background' => $description['background']));
                     $ext_cals[] = array(
                         'a' => $api,
                         'n' => $name,
                         'd' => $description['title'],
                         't' => $description['type'],
-                        'b' => empty($description['background']) ? '#dddddd' : $description['background']
+                        'b' => $description['background']
                     );
                 }
             }
@@ -512,7 +531,7 @@ class Kronolith_CalendarsManager
         }
         $prefs->setValue('display_external_cals', serialize($this->_displayExternal));
 
-        return $this->displayExternal;
+        return $this->_displayExternal;
     }
 
     /**
