@@ -3,7 +3,7 @@
  * Kronolith_Driver defines an API for implementing storage backends for
  * Kronolith.
  *
- * Copyright 1999-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 1999-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -148,7 +148,9 @@ class Kronolith_Driver
      * @param object $query  An object with the criteria to search for.
      * @param boolean $json  Store the results of the events' toJson() method?
      *
-     * @return mixed  An array of Kronolith_Events.
+     * @return array An array of search results keyed by date, with each date
+     *               containing an array of Kronolith_Events occuring on that
+     *               date.
      * @throws Kronolith_Exception
      */
     public function search($query, $json = false)
@@ -239,7 +241,7 @@ class Kronolith_Driver
      * @throws Kronolith_Exception
      * @throws Horde_Exception_NotFound
      */
-    public function getEvent()
+    public function getEvent($eventId = null)
     {
         throw new Kronolith_Exception($this->_errormsg);
     }
@@ -504,11 +506,15 @@ class Kronolith_Driver
 
         /* Remove any CalDAV mappings. */
         try {
-            $GLOBALS['injector']
-                ->getInstance('Horde_Dav_Storage')
-                ->deleteInternalObjectId($event->id, $event->calendar);
+            $davStorage = $GLOBALS['injector']
+                ->getInstance('Horde_Dav_Storage');
+            try {
+                $davStorage
+                    ->deleteInternalObjectId($event->id, $event->calendar);
+            } catch (Horde_Exception $e) {
+                Horde::log($e);
+            }
         } catch (Horde_Exception $e) {
-            Horde::log($e);
         }
 
         /* See if this event represents an exception - if so, touch the base
