@@ -9,7 +9,7 @@
  * - user:     The user name for HTTP Basic Authentication.
  * - password: The password for HTTP Basic Authentication.
  *
- * Copyright 2004-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2004-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -318,7 +318,18 @@ class Kronolith_Driver_Ical extends Kronolith_Driver
         for ($i = 0; $i < $count; $i++) {
             $component = $components[$i];
             if ($component->getType() == 'vEvent') {
-                $event = new Kronolith_Event_Ical($this, $component);
+                try {
+                    $event = new Kronolith_Event_Ical($this, $component);
+                } catch (Kronolith_Exception $e) {
+                    Horde::log(
+                        sprintf(
+                            'Failed parse event from remote calendar: url = "%s"',
+                            $this->calendar
+                        ),
+                        'INFO'
+                    );
+                    continue;
+                }
                 $event->permission = $this->getPermission();
                 // Force string so JSON encoding is consistent across drivers.
                 $event->id = $id ? $id : 'ical' . $i;
@@ -647,6 +658,7 @@ class Kronolith_Driver_Ical extends Kronolith_Driver
             if ($e->getCode() != 405) {
                 Horde::log($e, 'INFO');
             }
+            $this->_davSupport = false;
             return false;
         }
 
