@@ -11,7 +11,7 @@ require_once __DIR__ . '/../lib/Kronolith.php';
 /**
  * Adds tables for the Sqlng share driver.
  *
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.horde.org/licenses/gpl.
@@ -28,6 +28,10 @@ class KronolithUpgradeSqlng extends Horde_Db_Migration_Base
      */
     public function up()
     {
+        if (in_array('kronolith_sharesng', $this->tables())) {
+            return;
+        }
+
         $t = $this->createTable('kronolith_sharesng', array('autoincrementKey' => 'share_id'));
         $t->column('share_name', 'string', array('limit' => 255, 'null' => false));
         $t->column('share_owner', 'string', array('limit' => 255));
