@@ -15,7 +15,7 @@
 /**
  * Test importing iCalendar events.
  *
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPLv2). If you did not
  * receive this file, see http://www.horde.org/licenses/gpl
@@ -29,6 +29,17 @@
  */
 class Kronolith_Integration_FromIcalendarTest extends Kronolith_TestCase
 {
+    public function setUp()
+    {
+        $this->_timezone = date_default_timezone_get();
+        date_default_timezone_set('Europe/Berlin');
+    }
+
+    public function tearDown()
+    {
+        date_default_timezone_set($this->_timezone);
+    }
+
     public function testStart()
     {
         $event = $this->_getFixture('fromicalendar.ics');
