@@ -15,7 +15,7 @@
 /**
  * Test exporting iCalendar events.
  *
- * Copyright 2011-2014 Horde LLC (http://www.horde.org/)
+ * Copyright 2011-2015 Horde LLC (http://www.horde.org/)
  *
  * See the enclosed file COPYING for license information (GPLv2). If you did not
  * receive this file, see http://www.horde.org/licenses/gpl
@@ -31,6 +31,8 @@ class Kronolith_Integration_ToIcalendarTest extends Kronolith_TestCase
 {
     public function setUp()
     {
+        $this->_timezone = date_default_timezone_get();
+        date_default_timezone_set('Europe/Berlin');
         $GLOBALS['registry'] = new Kronolith_Stub_Registry('test', 'kronolith');
         $GLOBALS['injector'] = new Horde_Injector(new Horde_Injector_TopLevel());
         $GLOBALS['conf']['prefs']['driver'] = 'Null';
@@ -46,6 +48,7 @@ class Kronolith_Integration_ToIcalendarTest extends Kronolith_TestCase
         unset($GLOBALS['registry']);
         unset($GLOBALS['injector']);
         unset($GLOBALS['conf']);
+        date_default_timezone_set($this->_timezone);
     }
 
     public function testBasicVersion1()
@@ -91,7 +94,7 @@ class Kronolith_Integration_ToIcalendarTest extends Kronolith_TestCase
     private function _getEvent()
     {
         $GLOBALS['registry']->admin = true;
-        $event = new Kronolith_Event_Sql(new Kronolith_Stub_Driver(''));
+        $event = new Kronolith_Event_Mock(new Kronolith_Stub_Driver(''));
         $event->start = new Horde_Date('2007-03-15 13:10:20');
         $event->end = new Horde_Date('2007-03-15 14:20:00');
         $event->uid = '20070315143732.4wlenqz3edq8@horde.org';
